/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkIOExportOpenGLObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include "vtkIOExportOpenGLObjectFactory.h"
#include "vtkVersion.h"

// Include all of the classes we want to create overrides for.

#include "vtkOpenGLGL2PSExporter.h"

vtkStandardNewMacro(vtkIOExportOpenGLObjectFactory)

// Now create the functions to create overrides with.

  VTK_CREATE_CREATE_FUNCTION(vtkOpenGLGL2PSExporter)

vtkIOExportOpenGLObjectFactory::vtkIOExportOpenGLObjectFactory()
{

    this->RegisterOverride("vtkGL2PSExporter",
                           "vtkOpenGLGL2PSExporter",
                           "Override for vtkIOExportOpenGL module", 1,
                           vtkObjectFactoryCreatevtkOpenGLGL2PSExporter);
}

const char * vtkIOExportOpenGLObjectFactory::GetVTKSourceVersion()
{
  return VTK_SOURCE_VERSION;
}

void vtkIOExportOpenGLObjectFactory::PrintSelf(ostream &os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}

// Registration of object factories.
static unsigned int vtkIOExportOpenGLCount;

VTKIOEXPORTOPENGL_EXPORT void vtkIOExportOpenGL_AutoInit_Construct()
{
  if(++vtkIOExportOpenGLCount == 1)
    {
    
    vtkIOExportOpenGLObjectFactory* factory = vtkIOExportOpenGLObjectFactory::New();
    if (factory)
      {
      // vtkObjectFactory keeps a reference to the "factory",
      vtkObjectFactory::RegisterFactory(factory);
      factory->Delete();
      }
    }
}

VTKIOEXPORTOPENGL_EXPORT void vtkIOExportOpenGL_AutoInit_Destruct()
{
  if(--vtkIOExportOpenGLCount == 0)
    {
    // Do not call vtkObjectFactory::UnRegisterFactory because
    // vtkObjectFactory.cxx statically unregisters all factories.
    }
}
